# oLLL
A Python3 Implementation of LLL.

## Installation
```bash
python3 -m pip install olll
```
or
```bash
curl -O https://raw.githubusercontent.com/orisano/olll/master/olll.py
```

## Reference
https://en.wikipedia.org/wiki/Lenstra%E2%80%93Lenstra%E2%80%93Lov%C3%A1sz_lattice_basis_reduction_algorithm
